==> asn1tools-0.65.0.tar.gz: asn1tools-0.65.0/tests/files/x691_a3.py <==
EXPECTED = {'X691-A3': {'extensibility-implied': False,
             'imports': {},
             'object-classes': {},
             'object-sets': {},
             'types': {'ChildInformation': {'members': [{'name': 'name',
                                                         'type': 'Name'},
                                                        {'name': 'dateOfBirth',
                                                         'tag': {'number': 0},
                                                         'type': 'Date'},
                                                        '...',
                                                        {'name': 'sex',
                                                         'optional': True,
                                                         'tag': {'kind': 'IMPLICIT',
                                                                 'number': 1},
                                                         'type': 'ENUMERATED',
                                                         'values': [('male', 1),
                                                                    ('female',
                                                                     2),
                                                                    ('unknown',
                                                                     3)]}],
                                            'type': 'SET'},
                       'Date': {'tag': {'class': 'APPLICATION',
                                        'kind': 'IMPLICIT',
                                        'number': 3},
                                'permitted-alphabet': [('0', '9')],
                                'size': [8, '...', (9, 20)],
                                'type': 'VisibleString'},
                       'EmployeeNumber': {'restricted-to': [(0, 9999), '...'],
                                          'tag': {'class': 'APPLICATION',
                                                  'kind': 'IMPLICIT',
                                                  'number': 2},
                                          'type': 'INTEGER'},
                       'Name': {'members': [{'name': 'givenName',
                                             'type': 'NameString'},
                                            {'name': 'initial',
                                             'size': [1],
                                             'type': 'NameString'},
                                            {'name': 'familyName',
                                             'type': 'NameString'},
                                            '...'],
                                'tag': {'class': 'APPLICATION',
                                        'kind': 'IMPLICIT',
                                        'number': 1},
                                'type': 'SEQUENCE'},
                       'NameString': {'type': 'VisibleString',
                                      'permitted-alphabet': [('a', 'z'),
                                                             ('A', 'Z'),
                                                             ('-', '-'),
                                                             ('.', '.')],
                                      'size': [(1, 64), '...']},
                       'PersonnelRecord': {'members': [{'name': 'name',
                                                        'type': 'Name'},
                                                       {'name': 'title',
                                                        'tag': {'number': 0},
                                                        'type': 'VisibleString'},
                                                       {'name': 'number',
                                                        'type': 'EmployeeNumber'},
                                                       {'name': 'dateOfHire',
                                                        'tag': {'number': 1},
                                                        'type': 'Date'},
                                                       {'name': 'nameOfSpouse',
                                                        'tag': {'number': 2},
                                                        'type': 'Name'},
                                                       {'element': {'type': 'ChildInformation'},
                                                        'name': 'children',
                                                        'optional': True,
                                                        'size': [2, '...'],
                                                        'tag': {'kind': 'IMPLICIT',
                                                                'number': 3},
                                                        'type': 'SEQUENCE OF'},
                                                       '...'],
                                           'tag': {'class': 'APPLICATION',
                                                   'kind': 'IMPLICIT',
                                                   'number': 0},
                                           'type': 'SET'}},
             'values': {}}}

==> asn1tools-0.71.0.tar.gz: asn1tools-0.71.0/tests/files/x691_a3.py <==
EXPECTED = {'X691-A3': {'extensibility-implied': False,
             'imports': {},
             'object-classes': {},
             'object-sets': {},
             'types': {'ChildInformation': {'members': [{'name': 'name',
                                                         'type': 'Name'},
                                                        {'name': 'dateOfBirth',
                                                         'tag': {'number': 0},
                                                         'type': 'Date'},
                                                        None,
                                                        {'name': 'sex',
                                                         'optional': True,
                                                         'tag': {'kind': 'IMPLICIT',
                                                                 'number': 1},
                                                         'type': 'ENUMERATED',
                                                         'values': [('male', 1),
                                                                    ('female',
                                                                     2),
                                                                    ('unknown',
                                                                     3)]}],
                                            'type': 'SET'},
                       'Date': {'tag': {'class': 'APPLICATION',
                                        'kind': 'IMPLICIT',
                                        'number': 3},
                                'permitted-alphabet': [('0', '9')],
                                'size': [8, None, (9, 20)],
                                'type': 'VisibleString'},
                       'EmployeeNumber': {'restricted-to': [(0, 9999), None],
                                          'tag': {'class': 'APPLICATION',
                                                  'kind': 'IMPLICIT',
                                                  'number': 2},
                                          'type': 'INTEGER'},
                       'Name': {'members': [{'name': 'givenName',
                                             'type': 'NameString'},
                                            {'name': 'initial',
                                             'size': [1],
                                             'type': 'NameString'},
                                            {'name': 'familyName',
                                             'type': 'NameString'},
                                            None],
                                'tag': {'class': 'APPLICATION',
                                        'kind': 'IMPLICIT',
                                        'number': 1},
                                'type': 'SEQUENCE'},
                       'NameString': {'type': 'VisibleString',
                                      'permitted-alphabet': [('a', 'z'),
                                                             ('A', 'Z'),
                                                             ('-', '-'),
                                                             ('.', '.')],
                                      'size': [(1, 64), None]},
                       'PersonnelRecord': {'members': [{'name': 'name',
                                                        'type': 'Name'},
                                                       {'name': 'title',
                                                        'tag': {'number': 0},
                                                        'type': 'VisibleString'},
                                                       {'name': 'number',
                                                        'type': 'EmployeeNumber'},
                                                       {'name': 'dateOfHire',
                                                        'tag': {'number': 1},
                                                        'type': 'Date'},
                                                       {'name': 'nameOfSpouse',
                                                        'tag': {'number': 2},
                                                        'type': 'Name'},
                                                       {'element': {'type': 'ChildInformation'},
                                                        'name': 'children',
                                                        'optional': True,
                                                        'size': [2, None],
                                                        'tag': {'kind': 'IMPLICIT',
                                                                'number': 3},
                                                        'type': 'SEQUENCE OF'},
                                                       None],
                                           'tag': {'class': 'APPLICATION',
                                                   'kind': 'IMPLICIT',
                                                   'number': 0},
                                           'type': 'SET'}},
             'values': {}}}
